@@ -64,9 +64,9 @@ class quiver:
     
     def gov_contracts(self, ticker=""):
         if len(ticker)>0:
-            url = "https://api.quiverquant.com/beta/historical/govcontracts/"+ticker
+            url = "https://api.quiverquant.com/beta/historical/govcontractsall/"+ticker
         else:
-            url = "https://api.quiverquant.com/beta/live/govcontracts"
+            url = "https://api.quiverquant.com/beta/live/govcontractsall"
 
         r = requests.get(url, headers=self.headers)
         df = pd.DataFrame(json.loads(r.content))
@@ -193,8 +193,12 @@ class quiver:
         return df 
     
     def patents(self, ticker = ""):
-        url = "https://api.quiverquant.com/beta/historical/allpatents/"+ticker
-        
+        if len(ticker)<1:
+            url = "https://api.quiverquant.com/beta/live/allpatents"
+        else:
+            url = "https://api.quiverquant.com/beta/historical/allpatents/"+ticker
+       
+        print("Pulling data from: ", url)
         r = requests.get(url, headers=self.headers)
         
         if r.text == '"Upgrade your subscription plan to access this dataset."':
@@ -206,7 +210,7 @@ class quiver:
         return df
     
     ## Contact chris@quiverquant.com about access to these functions
-    def sec13F(self, ticker="", date="", owner=""):
+    def sec13F(self, ticker="", date="", owner="", period=""):
         separator = "?"
         url = "https://api.quiverquant.com/beta/live/sec13f"
         if len(ticker)>0:
@@ -218,6 +222,9 @@ class quiver:
         if len(owner)>0:
             url = url+separator+"owner="+owner
             separator="&"
+        if len(period)>0:
+            url = url+separator+"period="+period
+            separator="&"
             
         print("Pulling data from: ", url)     
         r = requests.get(url, headers=self.headers)
@@ -226,7 +233,23 @@ class quiver:
             raise NameError('Upgrade your subscription plan to access this dataset.')
             
         df = pd.DataFrame(json.loads(r.content))
-        df["Date"] = pd.to_datetime(df["Date"])
+        df["ReportPeriod"] = pd.to_datetime(df["ReportPeriod"], unit='ms')
+#         #Can edit this out once we get past May 25th
+#         values = []
+#         for val in df["Value"]:
+#             if len(val)>=900:
+#                 values.append(val[:len(val)//1000])
+#             else:
+#                 values.append(val)
+#         df["Value"] = values
+        ########
+        
+#         df["Value"] = df["Value"].str.replace(",", "")
+#         df["Value"] = df["Value"].astype(float)
+        
+#         df["Shares"] = df["Shares"].str.replace(",", "")
+#         df["Shares"] = df["Shares"].astype(float)
+        df["Date"] = pd.to_datetime(df["Date"], unit="ms")       
         return df
     
         
@@ -310,5 +333,31 @@ class quiver:
         df['Datetime'] = pd.to_datetime(df["Time"], unit='ms')
         return df 
     
+    def cryptoCommentsHistorical(self, ticker="", freq="", date_from = "", date_to = ""):
+        separator = "?"
+        url = "https://api.quiverquant.com/beta/live/cryptocommentsfull"
+        if len(ticker)>0:
+            url = url+separator+"ticker="+ticker
+            separator = "&"
+        if len(freq)>0:
+            url = url+separator+"freq="+freq
+            separator = "&"
+        if len(date_from)>0:
+            url = url+separator+"date_from="+date_from
+            separator = "&"   
+        if len(date_to)>0:
+            url = url+separator+"date_to="+date_to
+            separator = "&"   
+
+        print("Pulling data from: ", url)
+        r = requests.get(url, headers=self.headers)
+
+        if r.text == '"Upgrade your subscription plan to access this dataset."':
+            raise NameError('Upgrade your subscription plan to access this dataset. Contact chris@quiverquant.com with questions.')
+
+        df = pd.DataFrame(json.loads(r.content))
+        df['Datetime'] = pd.to_datetime(df["Time"], unit='ms')
+        return df 
+
 
   
